@@ -9,29 +9,21 @@ from uaclient.entitlements.entitlement_status import ApplicabilityStatus
 
 class TestValidServices:
     @pytest.mark.parametrize("show_all_names", ((True), (False)))
-    @pytest.mark.parametrize("allow_beta", ((True), (False)))
-    @pytest.mark.parametrize("is_beta", ((True), (False)))
-    @mock.patch("uaclient.entitlements.is_config_value_true")
     def test_valid_services(
         self,
-        m_is_config_value,
         show_all_names,
-        allow_beta,
-        is_beta,
         FakeConfig,
     ):
-        m_is_config_value.return_value = allow_beta
-
         m_cls_1 = mock.MagicMock()
         m_inst_1 = mock.MagicMock()
-        m_cls_1.is_beta = False
+        type(m_cls_1).name = mock.PropertyMock(return_value="ent1")
         m_inst_1.presentation_name = "ent1"
         m_inst_1.valid_names = ["ent1", "othername"]
         m_cls_1.return_value = m_inst_1
 
         m_cls_2 = mock.MagicMock()
         m_inst_2 = mock.MagicMock()
-        m_cls_2.is_beta = is_beta
+        type(m_cls_2).name = mock.PropertyMock(return_value="ent2")
         m_inst_2.presentation_name = "ent2"
         m_inst_2.valid_names = ["ent2"]
         m_cls_2.return_value = m_inst_2
@@ -39,9 +31,7 @@ class TestValidServices:
         ents = {m_cls_1, m_cls_2}
 
         with mock.patch.object(entitlements, "ENTITLEMENT_CLASSES", ents):
-            expected_services = ["ent1"]
-            if allow_beta or not is_beta:
-                expected_services.append("ent2")
+            expected_services = ["ent1", "ent2"]
             if show_all_names:
                 expected_services.append("othername")
 
@@ -54,23 +44,26 @@ class TestEntitlementFactory:
     def test_entitlement_factory(self, FakeConfig):
         m_cls_1 = mock.MagicMock()
         m_variant = mock.MagicMock()
+        m_variant_obj = m_variant.return_value
         m_cls_1.return_value.valid_names = ["ent1", "othername"]
         m_cls_1.return_value.variants = {"variant1": m_variant}
+        m_obj_1 = m_cls_1.return_value
 
         m_cls_2 = mock.MagicMock()
         m_cls_2.return_value.valid_names = ["ent2"]
+        m_obj_2 = m_cls_2.return_value
 
         ents = {m_cls_1, m_cls_2}
         cfg = FakeConfig()
 
         with mock.patch.object(entitlements, "ENTITLEMENT_CLASSES", ents):
-            assert m_cls_1 == entitlements.entitlement_factory(
+            assert m_obj_1 == entitlements.entitlement_factory(
                 cfg=cfg, name="othername"
             )
-            assert m_cls_2 == entitlements.entitlement_factory(
+            assert m_obj_2 == entitlements.entitlement_factory(
                 cfg=cfg, name="ent2"
             )
-            assert m_variant == entitlements.entitlement_factory(
+            assert m_variant_obj == entitlements.entitlement_factory(
                 cfg=cfg, name="ent1", variant="variant1"
             )
         with pytest.raises(exceptions.EntitlementNotFoundError):
@@ -94,16 +87,19 @@ class TestSortEntitlements:
     def test_disable_order(self, FakeConfig):
         m_cls_1 = mock.MagicMock()
         m_obj_1 = m_cls_1.return_value
+        m_obj_1.valid_names = ["ent1"]
         type(m_obj_1).dependent_services = mock.PropertyMock(return_value=())
         type(m_cls_1).name = mock.PropertyMock(return_value="ent1")
 
         m_cls_2 = mock.MagicMock()
         m_obj_2 = m_cls_2.return_value
+        m_obj_2.valid_names = ["ent2"]
         type(m_obj_2).dependent_services = mock.PropertyMock(return_value=())
         type(m_cls_2).name = mock.PropertyMock(return_value="ent2")
 
         m_cls_3 = mock.MagicMock()
         m_obj_3 = m_cls_3.return_value
+        m_obj_3.valid_names = ["ent3"]
         type(m_obj_3).dependent_services = mock.PropertyMock(
             return_value=(m_cls_1, m_cls_2)
         )
@@ -111,16 +107,19 @@ class TestSortEntitlements:
 
         m_cls_5 = mock.MagicMock()
         m_obj_5 = m_cls_5.return_value
+        m_obj_5.valid_names = ["ent5"]
         type(m_obj_5).dependent_services = mock.PropertyMock(return_value=())
         type(m_cls_5).name = mock.PropertyMock(return_value="ent5")
 
         m_cls_6 = mock.MagicMock()
         m_obj_6 = m_cls_6.return_value
+        m_obj_6.valid_names = ["ent6"]
         type(m_obj_6).dependent_services = mock.PropertyMock(return_value=())
         type(m_cls_6).name = mock.PropertyMock(return_value="ent6")
 
         m_cls_4 = mock.MagicMock()
         m_obj_4 = m_cls_4.return_value
+        m_obj_4.valid_names = ["ent4"]
         type(m_obj_4).dependent_services = mock.PropertyMock(
             return_value=(m_cls_5, m_cls_6)
         )
@@ -150,11 +149,13 @@ class TestSortEntitlements:
     def test_enable_order(self, FakeConfig):
         m_cls_2 = mock.MagicMock()
         m_obj_2 = m_cls_2.return_value
+        m_obj_2.valid_names = ["ent2"]
         type(m_obj_2).required_services = mock.PropertyMock(return_value=())
         type(m_cls_2).name = mock.PropertyMock(return_value="ent2")
 
         m_cls_1 = mock.MagicMock()
         m_obj_1 = m_cls_1.return_value
+        m_obj_1.valid_names = ["ent1"]
         type(m_obj_1).required_services = mock.PropertyMock(
             return_value=(mock.MagicMock(entitlement=m_cls_2),)
         )
@@ -162,6 +163,7 @@ class TestSortEntitlements:
 
         m_cls_3 = mock.MagicMock()
         m_obj_3 = m_cls_3.return_value
+        m_obj_3.valid_names = ["ent3"]
         type(m_obj_3).required_services = mock.PropertyMock(
             return_value=(
                 mock.MagicMock(entitlement=m_cls_1),
@@ -172,16 +174,19 @@ class TestSortEntitlements:
 
         m_cls_5 = mock.MagicMock()
         m_obj_5 = m_cls_5.return_value
+        m_obj_5.valid_names = ["ent5"]
         type(m_obj_5).required_services = mock.PropertyMock(return_value=())
         type(m_cls_5).name = mock.PropertyMock(return_value="ent5")
 
         m_cls_6 = mock.MagicMock()
         m_obj_6 = m_cls_6.return_value
+        m_obj_6.valid_names = ["ent6"]
         type(m_obj_6).required_services = mock.PropertyMock(return_value=())
         type(m_cls_6).name = mock.PropertyMock(return_value="ent6")
 
         m_cls_4 = mock.MagicMock()
         m_obj_4 = m_cls_4.return_value
+        m_obj_4.valid_names = ["ent4"]
         type(m_obj_4).required_services = mock.PropertyMock(
             return_value=(
                 mock.MagicMock(entitlement=m_cls_5),
@@ -214,11 +219,13 @@ class TestSortEntitlements:
     def test_order_entitlements_for_enabling(self, FakeConfig):
         m_cls_2 = mock.MagicMock()
         m_obj_2 = m_cls_2.return_value
+        m_obj_2.valid_names = ["ent2"]
         type(m_obj_2).required_services = mock.PropertyMock(return_value=())
         type(m_cls_2).name = mock.PropertyMock(return_value="ent2")
 
         m_cls_1 = mock.MagicMock()
         m_obj_1 = m_cls_1.return_value
+        m_obj_1.valid_names = ["ent1"]
         type(m_obj_1).required_services = mock.PropertyMock(
             return_value=(mock.MagicMock(entitlement=m_cls_2),)
         )
@@ -226,6 +233,7 @@ class TestSortEntitlements:
 
         m_cls_3 = mock.MagicMock()
         m_obj_3 = m_cls_3.return_value
+        m_obj_3.valid_names = ["ent3"]
         type(m_obj_3).required_services = mock.PropertyMock(
             return_value=(
                 mock.MagicMock(entitlement=m_cls_1),
@@ -236,16 +244,19 @@ class TestSortEntitlements:
 
         m_cls_5 = mock.MagicMock()
         m_obj_5 = m_cls_5.return_value
+        m_obj_5.valid_names = ["ent5"]
         type(m_obj_5).required_services = mock.PropertyMock(return_value=())
         type(m_cls_5).name = mock.PropertyMock(return_value="ent5")
 
         m_cls_6 = mock.MagicMock()
         m_obj_6 = m_cls_6.return_value
+        m_obj_6.valid_names = ["ent6"]
         type(m_obj_6).required_services = mock.PropertyMock(return_value=())
         type(m_cls_6).name = mock.PropertyMock(return_value="ent6")
 
         m_cls_4 = mock.MagicMock()
         m_obj_4 = m_cls_4.return_value
+        m_obj_4.valid_names = ["ent4"]
         type(m_obj_4).required_services = mock.PropertyMock(
             return_value=(
                 mock.MagicMock(entitlement=m_cls_5),
@@ -357,23 +368,19 @@ class TestCheckEntitlementAPTDefinitionsAreUnique:
     ):
         m_valid_services.return_value = ["ent1", "ent2"]
 
-        m_ent1 = mock.MagicMock()
         m_ent1_obj = mock.MagicMock()
         m_ent1_obj.applicability_status.return_value = applicability_status1
         type(m_ent1_obj).apt_url = apt_url1
         type(m_ent1_obj).apt_suites = suite1
         type(m_ent1_obj).repo_policy_check_tmpl = "{}/ubuntu {}"
-        m_ent1.return_value = m_ent1_obj
 
-        m_ent2 = mock.MagicMock()
         m_ent2_obj = mock.MagicMock()
         m_ent2_obj.applicability_status.return_value = applicability_status2
         type(m_ent2_obj).apt_url = apt_url2
         type(m_ent2_obj).apt_suites = suite2
         type(m_ent2_obj).repo_policy_check_tmpl = "{}/ubuntu {}"
-        m_ent2.return_value = m_ent2_obj
 
-        m_ent_factory.side_effect = [m_ent1, m_ent2]
+        m_ent_factory.side_effect = [m_ent1_obj, m_ent2_obj]
 
         if expected is True:
             assert entitlements.check_entitlement_apt_directives_are_unique(
@@ -386,3 +393,21 @@ class TestCheckEntitlementAPTDefinitionsAreUnique:
                 entitlements.check_entitlement_apt_directives_are_unique(
                     mock.MagicMock(url="test_url")
                 )
+
+
+class TestGetValidEntitlementNames:
+    @mock.patch(
+        "uaclient.entitlements.valid_services",
+        return_value=["ent1", "ent2", "ent3"],
+    )
+    def test_get_valid_entitlements(self, _m_valid_services, FakeConfig):
+        service = ["ent1", "ent3", "ent4"]
+        expected_ents_found = ["ent1", "ent3"]
+        expected_ents_not_found = ["ent4"]
+
+        actual_ents_found, actual_ents_not_found = (
+            entitlements.get_valid_entitlement_names(service, cfg=FakeConfig())
+        )
+
+        assert expected_ents_found == actual_ents_found
+        assert expected_ents_not_found == actual_ents_not_found
