@@ -34,6 +34,7 @@ from uaclient.apt import (
     get_apt_config_values,
     get_installed_packages_by_origin,
     get_installed_packages_names,
+    get_installed_packages_with_uninstalled_candidate_in_origin,
     get_pkg_candidate_version,
     get_remote_versions_for_package,
     get_system_sources_file,
@@ -915,28 +916,33 @@ class TestRemoveRepoFromAptAuthFile:
         assert after_content == auth_file.read("rb")
 
 
-class TestGetInstalledPackages:
-    @mock.patch("uaclient.apt.system.subp", return_value=("", ""))
-    def test_correct_command_called(self, m_subp):
-        get_installed_packages_names()
-
-        expected_call = mock.call(["apt", "list", "--installed"])
-        assert [expected_call] == m_subp.call_args_list
-
-    @mock.patch(
-        "uaclient.apt.system.subp", return_value=("Listing... Done\n", "")
-    )
-    def test_empty_output_means_empty_list(self, m_subp):
-        assert [] == get_installed_packages_names()
-
+class TestGetInstalledPackagesNames:
     @pytest.mark.parametrize(
-        "apt_list_return",
-        (APT_LIST_RETURN_STRING, APT_LIST_RETURN_STRING[:-1]),
+        [
+            "cache_packages",
+            "expected_result",
+        ],
+        [
+            (
+                [
+                    mock_package("one", mock_version("1", [])),
+                    mock_package("two"),  # not installed
+                    mock_package("three", mock_version("1", [])),
+                    mock_package("four", mock_version("1", [])),
+                ],
+                ["one", "three", "four"],
+            )
+        ],
     )
-    @mock.patch("uaclient.apt.system.subp")
-    def test_lines_are_split(self, m_subp, apt_list_return):
-        m_subp.return_value = apt_list_return, ""
-        assert ["a", "b"] == get_installed_packages_names()
+    @mock.patch("uaclient.apt.get_apt_pkg_cache")
+    def test_get_installed_packages_names(
+        self,
+        m_apt_cache,
+        cache_packages,
+        expected_result,
+    ):
+        m_apt_cache.return_value.packages = cache_packages
+        assert expected_result == get_installed_packages_names()
 
 
 class TestRunAptCommand:
@@ -1439,6 +1445,63 @@ class TestGetInstalledPackagesByOrigin:
         )
 
 
+class TestGetInstalledPackagesWithUninstalledCandidateByOrigin:
+    @pytest.mark.parametrize(
+        [
+            "origin",
+            "cache_packages",
+            "get_candidate_ver_side_effect",
+            "expected_result",
+        ],
+        [
+            (
+                "OriginA",
+                [
+                    mock_package("one", mock_version("1", [])),
+                    mock_package("two"),  # not installed
+                    mock_package("three", mock_version("1", [])),
+                    mock_package("four", mock_version("1", [])),
+                ],
+                [
+                    mock_version(
+                        "2", [mock_origin("main", "series", "OriginA", "")]
+                    ),
+                    mock_version(
+                        "2", [mock_origin("main", "series", "OriginB", "")]
+                    ),
+                    mock_version(
+                        "2", [mock_origin("main", "series", "OriginA", "")]
+                    ),
+                ],
+                ["four", "one"],
+            )
+        ],
+    )
+    @mock.patch("uaclient.apt.apt_pkg.DepCache")
+    @mock.patch("uaclient.apt.get_apt_pkg_cache")
+    def test_get_installed_packages_with_uninstalled_candidate_by_origin(
+        self,
+        m_apt_cache,
+        m_dep_cache,
+        origin,
+        cache_packages,
+        get_candidate_ver_side_effect,
+        expected_result,
+    ):
+        m_apt_cache.return_value.packages = cache_packages
+        m_dep_cache.return_value.get_candidate_ver.side_effect = (
+            get_candidate_ver_side_effect
+        )
+        assert expected_result == sorted(
+            [
+                p.name
+                for p in get_installed_packages_with_uninstalled_candidate_in_origin(  # noqa: E501
+                    origin
+                )
+            ]
+        )
+
+
 class TestGetRemoteVersionsForPackage:
     def test_get_remote_versions_for_package(self):
         assert ["0.9", "1.1"] == [
